@@ -186,7 +186,7 @@ class Dxr_Subscriber:
     def __init__(self, topic, callback):
         global callback_dit, topic_list_str_pub, topic_list_str_sub, mqttc, sn
         if sn is not None:
-            topic = '/' + sn + '/' + topic
+            topic = '/' + sn + topic
         if mqttc is None:
             mqttc = Mqtt()
         if isinstance(topic, str):
@@ -218,8 +218,6 @@ class dxr_subscriber:
             self.topic = msg
         else:
             self.topic = msg.topic
-        if sn is not None:
-            self.topic = '/' + sn + '/' + self.topic
         self.func = None
 
     def __call__(self, func):
@@ -232,7 +230,7 @@ class Dxr_Publisher:
     def __init__(self, topic):
         global publish_dit, topic_list_str_pub, topic_list_str_sub, callback_dit, mqttc, sn
         if sn is not None:
-            topic = '/' + sn + '/' + topic
+            topic = '/' + sn + topic
         if mqttc is None:
             mqttc = Mqtt()
         if isinstance(topic, str):
